<django-hstore-widget style='width:100%' delete_svg_src='/static/admin/img/icon-deletelink.svg' add_svg_src='/static/admin/img/icon-addlink.svg' edit_svg_src='/static/admin/img/icon-changelink.svg' field_name="{{ field_name }}" json="{{ field_data }}" />
