import{p as t,H as e,b as o}from"./p-DoOAkmu2.js";export{s as setNonce}from"./p-DoOAkmu2.js";import{g as r}from"./p-DQuL1Twl.js";var n=s=>{const t=s.cloneNode;s.cloneNode=function(s){if("TEMPLATE"===this.nodeName)return t.call(this,s);const e=t.call(this,!1),o=this.childNodes;if(s)for(let s=0;s<o.length;s++)2!==o[s].nodeType&&e.appendChild(o[s].cloneNode(!0));return e}};(()=>{n(e.prototype);const s=import.meta.url,o={};return""!==s&&(o.resourcesUrl=new URL(".",s).href),t(o)})().then((async s=>(await r(),o([["p-ffde156e",[[0,"django-hstore-widget",{json:[513],field_name:[513],cols:[514],rows:[514],delete_svg_src:[1],add_svg_src:[1],edit_svg_src:[1],mounted:[32],error:[32],textarea_value:[32],output_render_type:[32],__json:[32]},null,{json:["jsonWatcher"],__json:["__jsonWatcher"]}]]]],s))));